==> guikachu-1.5.0.tar.gz: guikachu-1.5.0/src/preferences-win.h <==
//$Id: preferences-win.h,v 1.6 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_PREFERENCES_WIN_H
#define GUIKACHU_PREFERENCES_WIN_H

#include <libglademm/xml.h>
#include <gtkmm/dialog.h>
#include <libgnomeuimm/color-picker.h>
#include <gtkmm/spinbutton.h>

namespace Guikachu
{
    namespace GUI
    {
	class PreferencesWin: public SigC::Object
	{
	    Glib::RefPtr<Gnome::Glade::Xml> gui;

	    Gtk::Dialog            *prop_box;
	    Gnome::UI::ColorPicker *color_fg, *color_disabled, *color_bg, *color_selection;
	    Gtk::SpinButton        *spin_zoom;
	    Gtk::Button            *apply_btn;
	    
	public:
	    PreferencesWin ();

	    void run ();
	    void update ();
	    void set_modified (bool modified);
	    void apply_cb ();

	    void color_changed_cb (guint r, guint g, guint b, guint a);
	};
    }
}

#endif /* !GUIKACHU_PREFERENCES_WIN_H */

==> guikachu-1.5.3.tar.gz: guikachu-1.5.3/src/preferences-win.h <==
//$Id: preferences-win.h,v 1.7 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_PREFERENCES_WIN_H
#define GUIKACHU_PREFERENCES_WIN_H

#include <libglademm/xml.h>
#include <gtkmm/dialog.h>
#include <libgnomeuimm/color-picker.h>
#include <gtkmm/spinbutton.h>

namespace Guikachu
{
    namespace GUI
    {
	class PreferencesWin: public sigc::trackable
	{
	    Glib::RefPtr<Gnome::Glade::Xml> gui;

	    Gtk::Dialog            *prop_box;
	    Gnome::UI::ColorPicker *color_fg, *color_disabled, *color_bg, *color_selection;
	    Gtk::SpinButton        *spin_zoom;
	    Gtk::Button            *apply_btn;
	    
	public:
	    PreferencesWin ();

	    void run ();
	    void update ();
	    void set_modified (bool modified);
	    void apply_cb ();

	    void color_changed_cb (guint r, guint g, guint b, guint a);
	};
    }
}

#endif /* !GUIKACHU_PREFERENCES_WIN_H */
